@@ -1,7 +1,9 @@
-import serial
-import os
 import getpass
-from kb_controller.helpers import kb_config, kb_central, microbit, event_poller, helper
+import os
+
+import serial
+
+from kb_controller.helpers import helper, kb_central, kb_config, microbit
 
 current_track_id = 0
 department_id = 0
@@ -31,8 +33,10 @@ def start():
 
     while True:
 
-        if current_track_id > 0 and event_poller.thread is None:
-            event_poller.start_thread(current_track_id)
+        # Do not make poll events automatically for now
+        # We let the micro:bit do that...
+        #if current_track_id > 0 and event_poller.thread is None:
+        #    event_poller.start_thread(current_track_id)
 
         try:
             byte_text = microbit.read_line()
@@ -50,7 +54,7 @@ def start():
                     track = text[5:]
                     if track == '0':
                         print()
-                        print("FEJL! Micro:bit'en er sat rigtig op - den står til bane ID = 0")
+                        print("FEJL! Micro:bit'en er ikke sat rigtig op - den står til bane ID = 0")
                         print()
                         response = 'ERROR:INIT:INVALID-TRACK:' + track
                     elif not track in tracks_per_department[department_id]['tracks']:
@@ -77,6 +81,7 @@ def start():
                     print('Henter events for kuglebanen')
                     print('-----------------------------')
                     count = kb_central.get_number_of_events_for_track(current_track_id)
+                    print(f'Antal beskeder modtaget til bane-ID: {current_track_id} = {count}')
                     response = f'OK:EVENTS-TRACK:{current_track_id}:{count}'
 
                 elif text.startswith('send:'):
@@ -149,8 +154,6 @@ def pop_event(events):
     event_id_to_pop = list(events['events'])[0]
     event = events['events'][event_id_to_pop]
 
-    kb_central.print_kb_event(event_id_to_pop, event)
-
     command_id = event['command_id']
     from_department_id = event['from_department_id']
     from_track_id = event['from_track_id']
