@@ -13,7 +13,7 @@ def kb_central_poller(current_track_id):
     while True:
         print()
         print('- - - - - - - - - - - - - - - - - - - - -')
-        print('Henter events fra kukglebane centralen...')
+        print('Henter events fra kuglebane centralen...')
         print()
 
         count = kb_central.get_number_of_events_for_track(current_track_id)
