@@ -44,7 +44,10 @@ def set_api_user(user, p):
 
 is_production = config['GENERAL'].getboolean('is_production')
 is_emulator = config['GENERAL'].getboolean('is_emulator')
-poll_interval_in_seconds = config['GENERAL'].getint('polling_interval')
+
+# Currently not used!!
+#poll_interval_in_seconds = config['GENERAL'].getint('polling_interval')
+
 EMULATOR = config['EMULATOR']
 MICROBIT = config['MICROBIT']
 LOCALHOST = config['LOCALHOST']
@@ -67,4 +70,4 @@ print(f'  tty_name             = {tty_name}')
 print(f'  tty_rate             = {tty_rate}')
 print(f'  tty_timeout          = {tty_timeout}')
 print(f'  kbc_host             = {kbc_host}')
-print(f'  polling_interval (s) = {poll_interval_in_seconds}')
\ No newline at end of file
+#print(f'  polling_interval (s) = {poll_interval_in_seconds}')
\ No newline at end of file
